==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/MergifyRule.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.768Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.MergifyRule")
@software.amazon.jsii.Jsii.Proxy(MergifyRule.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MergifyRule extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A dictionary made of Actions that will be executed on the matching pull requests.
     * <p>
     * @see https://docs.mergify.io/actions/#actions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getActions();

    /**
     * (experimental) A list of Conditions string that must match against the pull request for the rule to be applied.
     * <p>
     * @see https://docs.mergify.io/conditions/#conditions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.Object> getConditions();

    /**
     * (experimental) The name of the rule.
     * <p>
     * This is not used by the engine directly,
     * but is used when reporting information about a rule.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * @return a {@link Builder} of {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MergifyRule> {
        java.util.Map<java.lang.String, java.lang.Object> actions;
        java.util.List<java.lang.Object> conditions;
        java.lang.String name;

        /**
         * Sets the value of {@link MergifyRule#getActions}
         * @param actions A dictionary made of Actions that will be executed on the matching pull requests. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder actions(java.util.Map<java.lang.String, ? extends java.lang.Object> actions) {
            this.actions = (java.util.Map<java.lang.String, java.lang.Object>)actions;
            return this;
        }

        /**
         * Sets the value of {@link MergifyRule#getConditions}
         * @param conditions A list of Conditions string that must match against the pull request for the rule to be applied. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder conditions(java.util.List<? extends java.lang.Object> conditions) {
            this.conditions = (java.util.List<java.lang.Object>)conditions;
            return this;
        }

        /**
         * Sets the value of {@link MergifyRule#getName}
         * @param name The name of the rule. This parameter is required.
         *             This is not used by the engine directly,
         *             but is used when reporting information about a rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MergifyRule}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MergifyRule build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MergifyRule {
        private final java.util.Map<java.lang.String, java.lang.Object> actions;
        private final java.util.List<java.lang.Object> conditions;
        private final java.lang.String name;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.conditions = software.amazon.jsii.Kernel.get(this, "conditions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.actions = (java.util.Map<java.lang.String, java.lang.Object>)java.util.Objects.requireNonNull(builder.actions, "actions is required");
            this.conditions = (java.util.List<java.lang.Object>)java.util.Objects.requireNonNull(builder.conditions, "conditions is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getActions() {
            return this.actions;
        }

        @Override
        public final java.util.List<java.lang.Object> getConditions() {
            return this.conditions;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("actions", om.valueToTree(this.getActions()));
            data.set("conditions", om.valueToTree(this.getConditions()));
            data.set("name", om.valueToTree(this.getName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.MergifyRule"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MergifyRule.Jsii$Proxy that = (MergifyRule.Jsii$Proxy) o;

            if (!actions.equals(that.actions)) return false;
            if (!conditions.equals(that.conditions)) return false;
            return this.name.equals(that.name);
        }

        @Override
        public final int hashCode() {
            int result = this.actions.hashCode();
            result = 31 * result + (this.conditions.hashCode());
            result = 31 * result + (this.name.hashCode());
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/MergifyRule.java <==
package io.github.cdklabs.projen.github;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.434Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.MergifyRule")
@software.amazon.jsii.Jsii.Proxy(MergifyRule.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface MergifyRule extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A dictionary made of Actions that will be executed on the matching pull requests.
     * <p>
     * @see <a href="https://docs.mergify.io/actions/#actions">https://docs.mergify.io/actions/#actions</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getActions();

    /**
     * (experimental) A list of Conditions string that must match against the pull request for the rule to be applied.
     * <p>
     * @see <a href="https://docs.mergify.io/conditions/#conditions">https://docs.mergify.io/conditions/#conditions</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.Object> getConditions();

    /**
     * (experimental) The name of the rule.
     * <p>
     * This is not used by the engine directly,
     * but is used when reporting information about a rule.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getName();

    /**
     * @return a {@link Builder} of {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<MergifyRule> {
        java.util.Map<java.lang.String, java.lang.Object> actions;
        java.util.List<java.lang.Object> conditions;
        java.lang.String name;

        /**
         * Sets the value of {@link MergifyRule#getActions}
         * @param actions A dictionary made of Actions that will be executed on the matching pull requests. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder actions(java.util.Map<java.lang.String, ? extends java.lang.Object> actions) {
            this.actions = (java.util.Map<java.lang.String, java.lang.Object>)actions;
            return this;
        }

        /**
         * Sets the value of {@link MergifyRule#getConditions}
         * @param conditions A list of Conditions string that must match against the pull request for the rule to be applied. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder conditions(java.util.List<? extends java.lang.Object> conditions) {
            this.conditions = (java.util.List<java.lang.Object>)conditions;
            return this;
        }

        /**
         * Sets the value of {@link MergifyRule#getName}
         * @param name The name of the rule. This parameter is required.
         *             This is not used by the engine directly,
         *             but is used when reporting information about a rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MergifyRule}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public MergifyRule build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MergifyRule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MergifyRule {
        private final java.util.Map<java.lang.String, java.lang.Object> actions;
        private final java.util.List<java.lang.Object> conditions;
        private final java.lang.String name;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.conditions = software.amazon.jsii.Kernel.get(this, "conditions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.actions = (java.util.Map<java.lang.String, java.lang.Object>)java.util.Objects.requireNonNull(builder.actions, "actions is required");
            this.conditions = (java.util.List<java.lang.Object>)java.util.Objects.requireNonNull(builder.conditions, "conditions is required");
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getActions() {
            return this.actions;
        }

        @Override
        public final java.util.List<java.lang.Object> getConditions() {
            return this.conditions;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("actions", om.valueToTree(this.getActions()));
            data.set("conditions", om.valueToTree(this.getConditions()));
            data.set("name", om.valueToTree(this.getName()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.MergifyRule"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MergifyRule.Jsii$Proxy that = (MergifyRule.Jsii$Proxy) o;

            if (!actions.equals(that.actions)) return false;
            if (!conditions.equals(that.conditions)) return false;
            return this.name.equals(that.name);
        }

        @Override
        public final int hashCode() {
            int result = this.actions.hashCode();
            result = 31 * result + (this.conditions.hashCode());
            result = 31 * result + (this.name.hashCode());
            return result;
        }
    }
}
